@@ -227,7 +227,7 @@ class VariableOsDeviceArraySet(ReadonlyVariable):
     номером раздела добавляется "p": nvme0n1p1 вместо nvme0n11
     """
     type = "list"
-    devnames = ("nvme",)
+    devnames = ("nvme", "mmcblk")
 
     def get(self):
         """Get device partition table"""
@@ -362,6 +362,10 @@ class VariableOsDeviceName(ReadonlyVariable):
     Name of device
     """
     type = "list"
+    nameless_devices = {
+        'nvme': 'NVME',
+        'mmcblk': 'Multimedia Card'
+    }
 
     def getName(self, device):
         prop = getUdevDeviceInfo(name=device)
@@ -376,8 +380,10 @@ class VariableOsDeviceName(ReadonlyVariable):
             if vendor or model:
                 return ("%s %s" %
                         (vendor, model)).strip()
-            elif "nvme" in devicepath:
-                return "NVME"
+            else:
+                for k, v in self.nameless_devires.items():
+                    if k in devicepath:
+                        return v
             return ""
         else:
             return ""
